@@ -336,30 +336,29 @@ class DcsConnection:
         logging.info(str(id(self)) + " TID: " + str(tid) + "; Unknown MSG-Type received: " + str(msgtype) + ".")
     
     def watchdog(self):
-        logging.debug(str(id(self)) + " Watchdog running...")
-        self.__threadLock__.acquire()
-        if(self.__running__ != True):
-            self.__threadLock__.release()
-            return
+        logging.debug(str(id(self)) + " DCS-Watchdog running...")
+        with self.__threadLock__:
+            if(self.__running__ != True):
+                logging.warning(str(id(self)) + "DCS-Connection ist stopped.")
+                return
 
-        if(self.__receiverThread__ != None and not self.__receiverThread__.is_alive()):
-            logging.warning(str(id(self)) + " Receiver thread death. Restarting...")
-            try:
-                self.__receiverThread__ = self.__createReceiverThread__()
-                self.__receiverThread__.start()
-            except Exception as e:
-                logging.warning(str(id(self)) + " Error restarting receiver Thread: " + str(e))
-        
-        if(self.__workerThread__ != None and not self.__workerThread__.is_alive()):
-            logging.warning(str(id(self)) + " Worker thread death. Restarting...")
-            try:
-                self.__workerThread__.join(0.1)
-                self.__workerThread__ = self.__createWorkerThread__()
-                self.__workerThread__.start()
-            except Exception as e:
-                logging.warning(str(id(self)) + " Error restarting worker Thread: " + str(e))
-        self.__threadLock__.release()
-        
+            if(self.__receiverThread__ != None and not self.__receiverThread__.is_alive()):
+                logging.warning(str(id(self)) + " Receiver thread death. Restarting...")
+                try:
+                    self.__receiverThread__ = self.__createReceiverThread__()
+                    self.__receiverThread__.start()
+                except Exception as e:
+                    logging.warning(str(id(self)) + " Error restarting receiver Thread: " + str(e))
+            
+            if(self.__workerThread__ != None and not self.__workerThread__.is_alive()):
+                logging.warning(str(id(self)) + " Worker thread death. Restarting...")
+                try:
+                    self.__workerThread__.join(0.1)
+                    self.__workerThread__ = self.__createWorkerThread__()
+                    self.__workerThread__.start()
+                except Exception as e:
+                    logging.warning(str(id(self)) + " Error restarting worker Thread: " + str(e))
+            
         if(self.__lastMessageTime__ != None):
             difference = datetime.now() - self.__lastMessageTime__
             if(difference.total_seconds() > KEEPALIVETIMEOUT):
@@ -375,6 +374,12 @@ class DcsConnection:
                 self.reconnect()
             except Exception as e:
                 logging.warning(str(id(self)) + "Cannot reconect. " + str(e))
+        
+        try:
+            self.__checkSocket__()
+        except Exception as e:
+                logging.warning(str(id(self)) + "Cannot check socket. " + str(e))
+
         logging.debug(str(id(self)) + " MSQ-Size: " + str(self.__receivedMessageQueue__.qsize()))
 
     def __cleanSentrequests__(self):
@@ -413,12 +418,11 @@ class DcsConnection:
                 return False
 
     def __checkSocket__(self):
-        self.__socketLock__.acquire()
-        result = True
-        if self.__socket__ == None or self.__socket__._closed:
-            result = self.__openSocket__()
-        self.__socketLock__.release()
-        return result
+        with self.__socketLock__:
+            result = True
+            if self.__socket__ == None or self.__socket__._closed:
+                result = self.__openSocket__()
+            return result
 
     def __openSocket__(self):
         socketRetries = 0
